@@ -1,24 +1,28 @@
-( cd usr/man/man3 ; rm -rf pcap_minor_version.3pcap.gz )
-( cd usr/man/man3 ; ln -sf pcap_major_version.3pcap.gz pcap_minor_version.3pcap.gz )
-( cd usr/man/man3 ; rm -rf pcap_fopen_offline.3pcap.gz )
-( cd usr/man/man3 ; ln -sf pcap_open_offline.3pcap.gz pcap_fopen_offline.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_list_datalinks.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_free_datalinks.3pcap.gz pcap_list_datalinks.3pcap.gz )
 ( cd usr/man/man3 ; rm -rf pcap_dump_fopen.3pcap.gz )
 ( cd usr/man/man3 ; ln -sf pcap_dump_open.3pcap.gz pcap_dump_fopen.3pcap.gz )
 ( cd usr/man/man3 ; rm -rf pcap_sendpacket.3pcap.gz )
 ( cd usr/man/man3 ; ln -sf pcap_inject.3pcap.gz pcap_sendpacket.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_list_tstamp_types.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_free_tstamp_types.3pcap.gz pcap_list_tstamp_types.3pcap.gz )
 ( cd usr/man/man3 ; rm -rf pcap_dispatch.3pcap.gz )
 ( cd usr/man/man3 ; ln -sf pcap_loop.3pcap.gz pcap_dispatch.3pcap.gz )
-( cd usr/man/man3 ; rm -rf pcap_getnonblock.3pcap.gz )
-( cd usr/man/man3 ; ln -sf pcap_setnonblock.3pcap.gz pcap_getnonblock.3pcap.gz )
-( cd usr/man/man3 ; rm -rf pcap_next.3pcap.gz )
-( cd usr/man/man3 ; ln -sf pcap_next_ex.3pcap.gz pcap_next.3pcap.gz )
 ( cd usr/man/man3 ; rm -rf pcap_perror.3pcap.gz )
 ( cd usr/man/man3 ; ln -sf pcap_geterr.3pcap.gz pcap_perror.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_freealldevs.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_findalldevs.3pcap.gz pcap_freealldevs.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_next.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_next_ex.3pcap.gz pcap_next.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_fopen_offline.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_open_offline.3pcap.gz pcap_fopen_offline.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_minor_version.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_major_version.3pcap.gz pcap_minor_version.3pcap.gz )
 ( cd usr/man/man3 ; rm -rf pcap_datalink_val_to_description.3pcap.gz )
 ( cd usr/man/man3 ; ln -sf pcap_datalink_val_to_name.3pcap.gz pcap_datalink_val_to_description.3pcap.gz )
+( cd usr/man/man3 ; rm -rf pcap_getnonblock.3pcap.gz )
+( cd usr/man/man3 ; ln -sf pcap_setnonblock.3pcap.gz pcap_getnonblock.3pcap.gz )
+( cd usr/lib ; rm -rf libpcap.so.1 )
+( cd usr/lib ; ln -sf libpcap.so.1.3.0 libpcap.so.1 )
 ( cd usr/lib ; rm -rf libpcap.so )
 ( cd usr/lib ; ln -sf libpcap.so.1 libpcap.so )
-( cd usr/lib ; rm -rf libpcap.so.1 )
-( cd usr/lib ; ln -sf libpcap.so.1.1.1 libpcap.so.1 )
-( cd usr/lib ; rm -rf libpcap.so.0 )
-( cd usr/lib ; ln -sf libpcap.so.1 libpcap.so.0 )
